@@ -1,23 +1,28 @@
-# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import grt
 import mforms
 import migration
+import re
 
 from grt import DBLoginError
 from workbench.ui import WizardPage, WizardProgressPage
@@ -38,14 +43,15 @@ def ping_host(hostname):
     except:
         return False
 
-def request_password(connection, forget_old = False):
+def request_password(connection, username = '', storage_string = '', forget_old = False):
     # Get the password:
     for param in connection.driver.parameters:
         if param.paramType in ('keychain', 'password'):
             if param.paramType == 'keychain':
-                connection_params = get_connection_parameters(connection, do_not_transform=True)
-                storage_key_format = param.paramTypeDetails['storageKeyFormat']
-                username, storage_string = replace_string_parameters(storage_key_format, connection_params).split('::', 1)
+                if not username or not storage_string:
+                    connection_params = get_connection_parameters(connection, do_not_transform=True)
+                    storage_key_format = param.paramTypeDetails['storageKeyFormat']
+                    username, storage_string = replace_string_parameters(storage_key_format, connection_params).split('::', 1)
                 accepted, passwd = mforms.Utilities.find_or_ask_for_password('Enter password for user ' + username, storage_string, username, forget_old)
                 if accepted:
                     return passwd
@@ -246,7 +252,9 @@ class SourceWizardPage(WizardPage):
                         return
 
                 attempt += 1
-                source.password = request_password(source.connection, force_password)
+                username = source.connection.parameterValues.userName
+                storage_string = source.connection.hostIdentifier
+                source.password = request_password(source.connection, username, storage_string, force_password)
                 
                 # Avoid asking the password a second time when the user cancels the password request
                 if source.password == None:
@@ -443,7 +451,9 @@ class FetchProgressView(WizardProgressPage):
                         #if mforms.Utilities.show_error("Connect to Source RDBMS", str(e), "Retry", "Cancel", "") != mforms.ResultOk:
                         raise e
                 attempt += 1
-                self.main.plan.migrationSource.password = request_password(self.main.plan.migrationSource.connection, force_password)
+                username = self.main.plan.migrationSource.connection.parameterValues.userName
+                storage_string = self.main.plan.migrationSource.connection.hostIdentifier
+                self.main.plan.migrationSource.password = request_password(self.main.plan.migrationSource.connection, username, storage_string, force_password)
 
     def go_back(self):
         self.reset(True)
@@ -480,4 +490,6 @@ class FetchProgressView(WizardProgressPage):
                     else:
                         raise e
                 attempt += 1
-                self.main.plan.migrationTarget.password = request_password(self.main.plan.migrationTarget.connection)
+                username = self.main.plan.migrationTarget.connection.parameterValues.userName
+                storage_string = self.main.plan.migrationTarget.connection.hostIdentifier
+                self.main.plan.migrationTarget.password = request_password(self.main.plan.migrationTarget.connection, username, storage_string)
