@@ -1,20 +1,23 @@
-# Copyright (c) 2013, 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
-
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import mforms
 import grt 
@@ -742,6 +745,7 @@ class IndexManager(ObjectManager):
                ("Sub_part", StringColumnType, "Sub part", 50, None),
                ("Null", StringColumnType, "NULL", 50, None),
                ("Comment", StringColumnType, "Comment", 200, None)]
+    
     #actions = [("Manage Indexes", "manage")]
 
     def __init__(self, editor, schema, owner):
@@ -749,7 +753,10 @@ class IndexManager(ObjectManager):
 
         self.owner= owner
         self.table_manager = owner.tab_tables
-
+            
+    def preload_columns(self):
+        if self.target_version.is_supported_mysql_version_at_least(8, 0, 4):
+            self.columns.append(("Visible", StringColumnType, "Visible", 75, None))
 
     def manage(self):
         self.owner.show_index_manager()
